gs_quant.timeseries.datetime.day — gs_quant 0.1 documentation

# gs_quant.timeseries.datetime.day

`day`(x)

  Day of each value in series

  Parameters

    x (`Series`) – time series

  Return type

    `Series`

  Returns

    day of observations

  Usage

  Returns the day as a numeric value for each observation in the series:

  \(Y_t = day(t)\)

  Day of the time or date is the integer day number within the month, e.g. 1-31

  Examples

  Day for observations in series:

      >>> series = generate_series(100)
      >>> days = day(series)

  See also

  `month()` `year()`